@@ -9,7 +9,6 @@ importorskip("iniparse")
 
 
 class TestPO2Ini:
-
     ConverterClass = po2ini.po2ini
 
     def _convert(
@@ -280,11 +279,9 @@ class TestPO2IniCommand(test_convert.TestConvertCommand, TestPO2Ini):
 
     convertmodule = po2ini
     defaultoptions = {"progress": "none"}
-
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
-        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
-        options = self.help_check(options, "--threshold=PERCENT")
-        options = self.help_check(options, "--fuzzy")
-        options = self.help_check(options, "--nofuzzy", last=True)
+    expected_options = [
+        "-t TEMPLATE, --template=TEMPLATE",
+        "--threshold=PERCENT",
+        "--fuzzy",
+        "--nofuzzy",
+    ]
