@@ -303,7 +303,6 @@ else:
     # in docs/conf.py would work as well, but xml is likely always to be there.
     gpo = None
     if "xml" not in sys.modules or sys.modules["xml"].__path__ != "/dev/null":
-
         # Now we are getting desperate, so let's guess a unix type DLL that
         # might be in LD_LIBRARY_PATH or loaded with LD_PRELOAD
         try:
@@ -359,7 +358,6 @@ def gpo_decode(value):
 
 
 class pounit(pocommon.pounit):
-
     #: fixed encoding that is always used for cPO structure (self._gpo_message)
     CPO_ENC = "utf-8"
 
@@ -757,7 +755,7 @@ class pounit(pocommon.pounit):
         """Build a native unit from a foreign unit, preserving as much
         information as possible.
         """
-        if type(unit) == cls and hasattr(unit, "copy") and callable(unit.copy):
+        if type(unit) is cls and hasattr(unit, "copy") and callable(unit.copy):
             return unit.copy()
         elif isinstance(unit, pocommon.pounit):
             newunit = cls(unit.source, encoding)
@@ -819,7 +817,7 @@ class pofile(pocommon.pofile):
     def _insert_header(self, header):
         header._store = self
         self.units.insert(0, header)
-        gpo.po_message_iterator_free(self._gpo_message_iterator)
+        self._free_iterator()
         self._gpo_message_iterator = gpo.po_message_iterator(
             self._gpo_memory_file, None
         )
@@ -881,8 +879,9 @@ class pofile(pocommon.pofile):
         new_gpo_message_iterator = gpo.po_message_iterator(new_gpo_memory_file, None)
         for unit in uniqueunits:
             gpo.po_message_insert(new_gpo_message_iterator, unit._gpo_message)
-        gpo.po_message_iterator_free(self._gpo_message_iterator)
+        self._free_iterator()
         self._gpo_message_iterator = new_gpo_message_iterator
+        self._free_memory_file()
         self._gpo_memory_file = new_gpo_memory_file
         self.units = uniqueunits
 
@@ -901,11 +900,13 @@ class pofile(pocommon.pofile):
 
         def writefile(filename):
             xerror_storage.exception = None
-            self._gpo_memory_file = gpo.po_file_write_v2(
+            result = gpo.po_file_write_v2(
                 self._gpo_memory_file, gpo_encode(filename), xerror_handler
             )
             if xerror_storage.exception is not None:
                 raise xerror_storage.exception
+            if result is None:
+                raise ValueError("Unknown error while saving file")
             with open(filename, "rb") as tfile:
                 return tfile.read()
 
@@ -968,6 +969,7 @@ class pofile(pocommon.pofile):
 
         try:
             xerror_storage.exception = None
+            self._free_memory_file()
             self._gpo_memory_file = gpo.po_file_read_v3(
                 gpo_encode(input), xerror_handler
             )
@@ -989,6 +991,7 @@ class pofile(pocommon.pofile):
             if charset:
                 charset = re.search("charset=([^\\s]+)", charset).group(1)
             self.encoding = charset
+        self._free_iterator()
         self._gpo_message_iterator = gpo.po_message_iterator(
             self._gpo_memory_file, None
         )
@@ -1000,18 +1003,16 @@ class pofile(pocommon.pofile):
         self._free_iterator()
 
     def __del__(self):
-        # We currently disable this while we still get segmentation faults.
-        # Note that this is definitely leaking memory because of this.
-        return
         self._free_iterator()
+        self._free_memory_file()
+
+    def _free_memory_file(self):
+        return
         if self._gpo_memory_file is not None:
             gpo.po_file_free(self._gpo_memory_file)
             self._gpo_memory_file = None
 
     def _free_iterator(self):
-        # We currently disable this while we still get segmentation faults.
-        # Note that this is definitely leaking memory because of this.
-        return
         if self._gpo_message_iterator is not None:
             gpo.po_message_iterator_free(self._gpo_message_iterator)
             self._gpo_message_iterator = None
