@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 #
@@ -41,28 +40,28 @@ in very small files.
 
 import array
 import re
-import six
 import struct
 
 from translate.misc.multistring import multistring
 from translate.storage import base, poheader
 
 
-MO_MAGIC_NUMBER = 0x950412de
+MO_MAGIC_NUMBER = 0x950412DE
+POT_HEADER = re.compile(r"^POT-Creation-Date:.*(\n|$)", re.IGNORECASE | re.MULTILINE)
 
 
-def mounpack(filename='messages.mo'):
+def mounpack(filename="messages.mo"):
     """Helper to unpack Gettext MO files into a Python string"""
-    with open(filename, 'rb') as fh:
+    with open(filename, "rb") as fh:
         s = fh.read()
         print("\\x%02x" * len(s) % tuple(map(ord, s)))
 
 
 def my_swap4(result):
-    c0 = (result >> 0) & 0xff
-    c1 = (result >> 8) & 0xff
-    c2 = (result >> 16) & 0xff
-    c3 = (result >> 24) & 0xff
+    c0 = (result >> 0) & 0xFF
+    c1 = (result >> 8) & 0xFF
+    c2 = (result >> 16) & 0xFF
+    c3 = (result >> 24) & 0xFF
 
     return (c0 << 24) | (c1 << 16) | (c2 << 8) | c3
 
@@ -70,36 +69,40 @@ def my_swap4(result):
 def hashpjw(str_param):
     HASHWORDBITS = 32
     hval = 0
-    g = None
-    s = str_param
     for s in str_param:
+        if not s:
+            break
         hval = hval << 4
-        hval += ord(s) if six.PY2 else s
-        g = hval & 0xf << (HASHWORDBITS - 4)
-        if (g != 0):
-            hval = hval ^ g >> (HASHWORDBITS - 8)
+        hval += s
+        g = hval & 0xF << (HASHWORDBITS - 4)
+        if g != 0:
+            hval = hval ^ (g >> (HASHWORDBITS - 8))
             hval = hval ^ g
     return hval
 
 
 def get_next_prime_number(start):
     # find the smallest prime number that is greater or equal "start"
+    # this is based on hash lib implementation in gettext
 
     def is_prime(num):
-        # special small numbers
-        if (num < 2) or (num == 4):
-            return False
-        if (num == 2) or (num == 3):
-            return True
-        # check for numbers > 4
-        for divider in range(2, num // 2):
-            if num % divider == 0:
-                return False
-        return True
+        # No even number and none less than 10 will be passed here
+        divn = 3
+        sq = divn * divn
+
+        while sq < num and num % divn != 0:
+            divn += 1
+            sq += 4 * divn
+            divn += 1
+
+        return num % divn != 0
+
+    # Make it definitely odd
+    candidate = start | 1
 
-    candidate = start
     while not is_prime(candidate):
-        candidate += 1
+        candidate += 2
+
     return candidate
 
 
@@ -109,7 +112,7 @@ class mounit(base.TranslationUnit):
     def __init__(self, source=None, **kwargs):
         self.msgctxt = []
         self.msgidcomments = []
-        super(mounit, self).__init__(source)
+        super().__init__(source)
 
     def getcontext(self):
         """Get the message context"""
@@ -118,9 +121,12 @@ class mounit(base.TranslationUnit):
             return None
         return "".join(self.msgctxt)
 
+    def setcontext(self, context):
+        self.msgctxt = [context]
+
     def isheader(self):
         """Is this a header entry?"""
-        return self.source == u""
+        return self.source == ""
 
     def istranslatable(self):
         """Is this message translateable?"""
@@ -137,8 +143,8 @@ class mofile(poheader.poheader, base.TranslationStore):
     _binary = True
 
     def __init__(self, inputfile=None, **kwargs):
-        super(mofile, self).__init__(**kwargs)
-        self.filename = ''
+        super().__init__(**kwargs)
+        self.filename = ""
         if inputfile is not None:
             self.parsestring(inputfile)
 
@@ -147,28 +153,21 @@ class mofile(poheader.poheader, base.TranslationStore):
         # check the header of this file for the copyright note of this function
 
         def add_to_hash_table(string, i):
-            V = hashpjw(string)
-            # Taken from gettext-0.17:gettext-tools/src/write-mo.c:408-409
-            S = hash_size <= 2 and 3 or hash_size
-            hash_cursor = V % S
-            orig_hash_cursor = hash_cursor
-            increment = 1 + (V % (S - 2))
-            while True:
-                index = hash_table[hash_cursor]
-                if (index == 0):
-                    hash_table[hash_cursor] = i + 1
-                    break
+            hash_value = hashpjw(string)
+            hash_cursor = hash_value % hash_size
+            increment = 1 + (hash_value % (hash_size - 2))
+            while hash_table[hash_cursor] != 0:
                 hash_cursor += increment
-                hash_cursor = hash_cursor % S
-                assert (hash_cursor != orig_hash_cursor)
+                hash_cursor = hash_cursor % hash_size
+            hash_table[hash_cursor] = i + 1
 
-        def lst_encode(lst, join_char=b''):
-            return join_char.join([i.encode('utf-8') for i in lst])
+        def lst_encode(lst, join_char=b""):
+            return join_char.join([i.encode("utf-8") for i in lst])
 
         # hash_size should be the smallest prime number that is greater
         # or equal (4 / 3 * N) - where N is the number of keys/units.
         # see gettext-0.17:gettext-tools/src/write-mo.c:406
-        hash_size = get_next_prime_number(int((len(self.units) * 4) / 3))
+        hash_size = get_next_prime_number((len(self.units) * 4) // 3)
         if hash_size <= 2:
             hash_size = 3
         MESSAGES = {}
@@ -177,16 +176,21 @@ class mofile(poheader.poheader, base.TranslationStore):
             if not unit.istranslated():
                 continue
             if isinstance(unit.source, multistring):
-                source = (lst_encode(unit.msgidcomments) +
-                          lst_encode(unit.source.strings, b"\0"))
+                source = lst_encode(unit.msgidcomments) + lst_encode(
+                    unit.source.strings, b"\0"
+                )
             else:
-                source = lst_encode(unit.msgidcomments) + unit.source.encode('utf-8')
+                source = lst_encode(unit.msgidcomments) + unit.source.encode("utf-8")
             if unit.msgctxt:
                 source = lst_encode(unit.msgctxt) + b"\x04" + source
             if isinstance(unit.target, multistring):
                 target = lst_encode(unit.target.strings, b"\0")
+            elif unit.isheader():
+                # Support for "reproducible builds": Delete information that
+                # may vary between builds in the same conditions.
+                target = POT_HEADER.sub("", unit.target).encode("utf-8")
             else:
-                target = unit.target.encode('utf-8')
+                target = unit.target.encode("utf-8")
             if unit.target:
                 MESSAGES[source] = target
         # using "I" works for 32- and 64-bit systems, but not for 16-bit!
@@ -194,7 +198,7 @@ class mofile(poheader.poheader, base.TranslationStore):
         # the keys are sorted in the .mo file
         keys = sorted(MESSAGES.keys())
         offsets = []
-        ids = strs = b''
+        ids = strs = b""
         for i, id in enumerate(keys):
             # For each string, we need size and file offset.  Each string is
             # NUL terminated; the NUL does not count into the size.
@@ -202,9 +206,8 @@ class mofile(poheader.poheader, base.TranslationStore):
             add_to_hash_table(id, i)
             string = MESSAGES[id]  # id already encoded for use as dictionary key
             offsets.append((len(ids), len(id), len(strs), len(string)))
-            ids = ids + id + b'\0'
-            strs = strs + string + b'\0'
-        output = ''
+            ids = ids + id + b"\0"
+            strs = strs + string + b"\0"
         # The header is 7 32-bit unsigned integers
         keystart = 7 * 4 + 16 * len(keys) + hash_size * 4
         # and the values start after the keys
@@ -217,68 +220,87 @@ class mofile(poheader.poheader, base.TranslationStore):
             koffsets = koffsets + [l1, o1 + keystart]
             voffsets = voffsets + [l2, o2 + valuestart]
         offsets = koffsets + voffsets
-        output = struct.pack("Iiiiiii",
-                             MO_MAGIC_NUMBER,   # Magic
-                             0,                 # Version
-                             len(keys),         # # of entries
-                             7 * 4,             # start of key index
-                             7 * 4 + len(keys) * 8,  # start of value index
-                             hash_size,         # size of hash table
-                             7 * 4 + 2 * (len(keys) * 8))  # offset of hash table
+        out.write(
+            struct.pack(
+                "Iiiiiii",
+                MO_MAGIC_NUMBER,  # Magic
+                0,  # Version
+                len(keys),  # # of entries
+                7 * 4,  # start of key index
+                7 * 4 + len(keys) * 8,  # start of value index
+                hash_size,  # size of hash table
+                7 * 4 + 2 * (len(keys) * 8),  # offset of hash table
+            )
+        )
         # additional data is not necessary for empty mo files
-        if (len(keys) > 0):
-            output = output + array.array("i", offsets).tostring()
-            output = output + hash_table.tostring()
-            output = output + ids
-            output = output + strs
-        return out.write(output)
+        if len(keys) > 0:
+            out.write(array.array("i", offsets).tobytes())
+            out.write(hash_table.tobytes())
+            out.write(ids)
+            out.write(strs)
 
     def parse(self, input):
         """parses the given file or file source string"""
-        if hasattr(input, 'name'):
+        if hasattr(input, "name"):
             self.filename = input.name
-        elif not getattr(self, 'filename', ''):
-            self.filename = ''
+        elif not getattr(self, "filename", ""):
+            self.filename = ""
         if hasattr(input, "read"):
             mosrc = input.read()
             input.close()
             input = mosrc
-        little, = struct.unpack("<L", input[:4])
-        big, = struct.unpack(">L", input[:4])
+        (little,) = struct.unpack("<L", input[:4])
+        (big,) = struct.unpack(">L", input[:4])
         if little == MO_MAGIC_NUMBER:
             endian = "<"
         elif big == MO_MAGIC_NUMBER:
             endian = ">"
         else:
             raise ValueError("This is not an MO file")
-        magic, version_maj, version_min, lenkeys, startkey, \
-            startvalue, sizehash, offsethash = struct.unpack("%sLHHiiiii" % endian,
-                                                             input[:(7 * 4)])
+        (
+            _magic,
+            version_maj,
+            version_min,
+            lenkeys,
+            startkey,
+            startvalue,
+            _sizehash,
+            _offsethash,
+        ) = struct.unpack("%sLHHiiiii" % endian, input[: (7 * 4)])
         if version_maj >= 1:
-            raise base.ParseError("""Unable to process version %d.%d MO files""" % (version_maj, version_min))
+            raise base.ParseError(
+                """Unable to process version %d.%d MO files"""
+                % (version_maj, version_min)
+            )
         for i in range(lenkeys):
             nextkey = startkey + (i * 2 * 4)
             nextvalue = startvalue + (i * 2 * 4)
-            klength, koffset = struct.unpack("%sii" % endian,
-                                             input[nextkey:nextkey + (2 * 4)])
-            vlength, voffset = struct.unpack("%sii" % endian,
-                                             input[nextvalue:nextvalue + (2 * 4)])
-            source = input[koffset:koffset + klength]
+            klength, koffset = struct.unpack(
+                "%sii" % endian, input[nextkey : nextkey + (2 * 4)]
+            )
+            vlength, voffset = struct.unpack(
+                "%sii" % endian, input[nextvalue : nextvalue + (2 * 4)]
+            )
+            source = input[koffset : koffset + klength]
             context = None
             if b"\x04" in source:
                 context, source = source.split(b"\x04")
             # Still need to handle KDE comments
             if source == "":
-                charset = re.search(b"charset=([^\\s]+)",
-                                    input[voffset:voffset + vlength])
+                charset = re.search(
+                    b"charset=([^\\s]+)", input[voffset : voffset + vlength]
+                )
                 if charset:
                     self.encoding = charset.group(1)
-            source = multistring([s.decode(self.encoding)
-                                  for s in source.split(b"\0")])
-            target = multistring([s.decode(self.encoding)
-                                  for s in input[voffset:voffset + vlength].split(b"\0")])
+            source = multistring([s.decode(self.encoding) for s in source.split(b"\0")])
+            target = multistring(
+                [
+                    s.decode(self.encoding)
+                    for s in input[voffset : voffset + vlength].split(b"\0")
+                ]
+            )
             newunit = mounit(source)
             newunit.target = target
             if context is not None:
-                newunit.msgctxt.append(context)
+                newunit.msgctxt.append(context.decode(self.encoding))
             self.addunit(newunit)
