@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2006-2009 Zuza Software Foundation
 #
@@ -24,12 +23,9 @@ This way the API supports plurals as if it was a PO file, for example.
 """
 
 import re
-import six
 
 from lxml import etree
 
-from translate.lang import data
-from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.misc.xml_helpers import setXMLspace
 from translate.storage import base, lisa, poheader, xliff
@@ -57,7 +53,7 @@ class PoXliffUnit(xliff.xliffunit):
             return
 
         if not hasplurals(source):
-            super(PoXliffUnit, self).__init__(source)
+            super().__init__(source)
             return
 
         self.xmlelement = etree.Element(self.namespaced("group"))
@@ -68,46 +64,41 @@ class PoXliffUnit(xliff.xliffunit):
         if isinstance(other, PoXliffUnit):
             if len(self.units) != len(other.units):
                 return False
-            if not super(PoXliffUnit, self).__eq__(other):
+            if not super().__eq__(other):
                 return False
             for i in range(len(self.units) - 1):
-                if not self.units[i+1] == other.units[i+1]:
+                if not self.units[i + 1] == other.units[i + 1]:
                     return False
             return True
         if len(self.units) <= 1:
             if isinstance(other, lisa.LISAunit):
-                return super(PoXliffUnit, self).__eq__(other)
+                return super().__eq__(other)
             else:
                 return self.source == other.source and self.target == other.target
         return False
 
-#XXX: We don't return language nodes correctly at the moment
-#    def getlanguageNodes(self):
-#        if not self.hasplural():
-#            return super(PoXliffUnit, self).getlanguageNodes()
-#        else:
-#            return self.units[0].getlanguageNodes()
+    # XXX: We don't return language nodes correctly at the moment
+    #    def getlanguageNodes(self):
+    #        if not self.hasplural():
+    #            return super().getlanguageNodes()
+    #        else:
+    #            return self.units[0].getlanguageNodes()
 
     @property
     def source(self):
         if not self.hasplural():
-            return super(PoXliffUnit, self).source
+            return super().source
         return multistring([unit.source for unit in self.units])
 
     @source.setter
     def source(self, source):
         self.setsource(source, sourcelang="en")
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
-
     def setsource(self, source, sourcelang="en"):
         # TODO: consider changing from plural to singular, etc.
         self._rich_source = None
         if not hasplurals(source):
-            super(PoXliffUnit, self).setsource(source, sourcelang)
+            super().setsource(source, sourcelang)
         else:
             target = self.target
             for unit in self.units:
@@ -118,7 +109,7 @@ class PoXliffUnit(xliff.xliffunit):
             self.units = []
             for s in source.strings:
                 newunit = xliff.xliffunit(s)
-#                newunit.namespace = self.namespace #XXX?necessary?
+                #                newunit.namespace = self.namespace #XXX?necessary?
                 self.units.append(newunit)
                 self.xmlelement.append(newunit.xmlelement)
             self.target = target
@@ -132,20 +123,20 @@ class PoXliffUnit(xliff.xliffunit):
 
     def gettarget(self, lang=None):
         if self.hasplural():
-            strings = [data.forceunicode(unit.target) for unit in self.units]
+            strings = [unit.target for unit in self.units]
             if strings:
                 return multistring(strings)
             else:
                 return None
         else:
-            return super(PoXliffUnit, self).gettarget(lang)
+            return super().gettarget(lang)
 
-    def settarget(self, target, lang='xx', append=False):
+    def settarget(self, target, lang="xx", append=False):
         self._rich_target = None
         if self.target == target:
             return
         if not self.hasplural():
-            super(PoXliffUnit, self).settarget(target, lang, append)
+            super().settarget(target, lang, append)
             return
         if not isinstance(target, multistring):
             target = multistring(target)
@@ -168,8 +159,6 @@ class PoXliffUnit(xliff.xliffunit):
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in a "note" tag"""
-        if isinstance(text, bytes):
-            text = text.decode("utf-8")
         note = etree.SubElement(self.xmlelement, self.namespaced("note"))
         note.text = text
         if origin:
@@ -178,19 +167,18 @@ class PoXliffUnit(xliff.xliffunit):
             unit.addnote(text, origin)
 
     def getnotes(self, origin=None):
-        #NOTE: We support both <context> and <note> tags in xliff files for comments
+        # NOTE: We support both <context> and <note> tags in xliff files for comments
         if origin == "translator":
-            notes = super(PoXliffUnit, self).getnotes("translator")
+            notes = super().getnotes("translator")
             trancomments = self.gettranslatorcomments()
             if notes == trancomments or trancomments.find(notes) >= 0:
                 notes = ""
             elif notes.find(trancomments) >= 0:
                 trancomments = notes
                 notes = ""
-            trancomments = trancomments + notes
-            return trancomments
+            return trancomments + notes
         elif origin in ["programmer", "developer", "source code"]:
-            devcomments = super(PoXliffUnit, self).getnotes("developer")
+            devcomments = super().getnotes("developer")
             autocomments = self.getautomaticcomments()
             if devcomments == autocomments or autocomments.find(devcomments) >= 0:
                 devcomments = ""
@@ -199,20 +187,20 @@ class PoXliffUnit(xliff.xliffunit):
                 devcomments = ""
             return autocomments
         else:
-            return super(PoXliffUnit, self).getnotes(origin)
+            return super().getnotes(origin)
 
     def markfuzzy(self, value=True):
-        super(PoXliffUnit, self).markfuzzy(value)
+        super().markfuzzy(value)
         for unit in self.units[1:]:
             unit.markfuzzy(value)
 
     def marktranslated(self):
-        super(PoXliffUnit, self).marktranslated()
+        super().marktranslated()
         for unit in self.units[1:]:
             unit.marktranslated()
 
     def setid(self, id):
-        super(PoXliffUnit, self).setid(id)
+        super().setid(id)
         if len(self.units) > 1:
             for i in range(len(self.units)):
                 self.units[i].setid("%s[%d]" % (id, i))
@@ -224,7 +212,7 @@ class PoXliffUnit(xliff.xliffunit):
         for group in groups:
             sourcefile = ""
             linenumber = ""
-            for (type, text) in group:
+            for type, text in group:
                 if type == "sourcefile":
                     sourcefile = text
                 elif type == "linenumber":
@@ -239,37 +227,33 @@ class PoXliffUnit(xliff.xliffunit):
         """Returns the automatic comments (x-po-autocomment), which corresponds
         to the #. style po comments.
         """
-
-        def hasautocomment(grp):
-            return grp[0] == "x-po-autocomment"
         groups = self.getcontextgroups("po-entry")
-        comments = []
-        for group in groups:
-            commentpairs = filter(hasautocomment, group)
-            for (type, text) in commentpairs:
-                comments.append(text)
+        comments = [
+            text
+            for group in groups
+            for ctype, text in group
+            if ctype == "x-po-autocomment"
+        ]
         return "\n".join(comments)
 
     def gettranslatorcomments(self):
         """Returns the translator comments (x-po-trancomment), which
         corresponds to the # style po comments.
         """
-
-        def hastrancomment(grp):
-            return grp[0] == "x-po-trancomment"
         groups = self.getcontextgroups("po-entry")
-        comments = []
-        for group in groups:
-            commentpairs = filter(hastrancomment, group)
-            for (type, text) in commentpairs:
-                comments.append(text)
+        comments = [
+            text
+            for group in groups
+            for ctype, text in group
+            if ctype == "x-po-trancomment"
+        ]
         return "\n".join(comments)
 
     def isheader(self):
         return "gettext-domain-header" in (self.getrestype() or "")
 
     def istranslatable(self):
-        return super(PoXliffUnit, self).istranslatable() and not self.isheader()
+        return super().istranslatable() and not self.isheader()
 
     @classmethod
     def createfromxmlElement(cls, element, namespace=None):
@@ -282,7 +266,7 @@ class PoXliffUnit(xliff.xliffunit):
         group = cls(None, empty=True)
         group.xmlelement = element
         group.namespace = namespace
-        units = list(element.iterdescendants(group.namespaced('trans-unit')))
+        units = list(element.iterdescendants(group.namespaced("trans-unit")))
         for unit in units:
             subunit = xliff.xliffunit.createfromxmlElement(unit)
             subunit.namespace = namespace
@@ -306,7 +290,9 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
     def createfilenode(self, filename, sourcelanguage="en-US", datatype="po"):
         # Let's ignore the sourcelanguage parameter opting for the internal
         # one. PO files will probably be one language
-        return super(PoXliffFile, self).createfilenode(filename, sourcelanguage=self.sourcelanguage, datatype="po")
+        return super().createfilenode(
+            filename, sourcelanguage=self.sourcelanguage, datatype="po"
+        )
 
     def _insert_header(self, header):
         header.xmlelement.set("restype", "x-gettext-domain-header")
@@ -322,44 +308,9 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
         setXMLspace(unit.xmlelement, "preserve")
         return unit
 
-    def addplural(self, source, target, filename, createifmissing=False):
-        """This method should now be unnecessary, but is left for reference"""
-        assert isinstance(source, multistring)
-        if not isinstance(target, multistring):
-            target = multistring(target)
-        sourcel = len(source.strings)
-        targetl = len(target.strings)
-        if sourcel < targetl:
-            sources = source.strings + [source.strings[-1]] * targetl - sourcel
-            targets = target.strings
-        else:
-            sources = source.strings
-            targets = target.strings
-        self._messagenum += 1
-        pluralnum = 0
-        group = self.creategroup(filename, True, restype="x-gettext-plural")
-        for (src, tgt) in zip(sources, targets):
-            unit = self.UnitClass(src)
-            unit.target = tgt
-            unit.setid("%d[%d]" % (self._messagenum, pluralnum))
-            pluralnum += 1
-            group.append(unit.xmlelement)
-            self.units.append(unit)
-
-        if pluralnum < sourcel:
-            for string in sources[pluralnum:]:
-                unit = self.UnitClass(src)
-                unit.xmlelement.set("translate", "no")
-                unit.setid("%d[%d]" % (self._messagenum, pluralnum))
-                pluralnum += 1
-                group.append(unit.xmlelement)
-                self.units.append(unit)
-
-        return self.units[-pluralnum]
-
     def parse(self, xml):
         """Populates this object from the given xml string"""
-        #TODO: Make more robust
+        # TODO: Make more robust
 
         def ispluralgroup(node):
             """determines whether the xml node refers to a getttext plural"""
@@ -371,13 +322,15 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
             We want to filter out all the plural nodes, except the very first
             one in each group.
             """
-            return re.match(r"\d+\[[123456]\]$", node.get("id") or "") is None
+            return re.match(r".+\[[123456]\]$", node.get("id") or "") is None
 
         def pluralunits(pluralgroups):
             for pluralgroup in pluralgroups:
-                yield self.UnitClass.createfromxmlElement(pluralgroup, namespace=self.namespace)
+                yield self.UnitClass.createfromxmlElement(
+                    pluralgroup, namespace=self.namespace
+                )
 
-        self.filename = getattr(xml, 'name', '')
+        self.filename = getattr(xml, "name", "")
         if hasattr(xml, "read"):
             xml.seek(0)
             xmlsrc = xml.read()
@@ -389,7 +342,9 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
         assert root_node.tag == self.namespaced(self.rootNode)
         groups = root_node.iterdescendants(self.namespaced("group"))
         pluralgroups = filter(ispluralgroup, groups)
-        termEntries = root_node.iterdescendants(self.namespaced(self.UnitClass.rootNode))
+        termEntries = root_node.iterdescendants(
+            self.namespaced(self.UnitClass.rootNode)
+        )
 
         singularunits = list(filter(isnonpluralunit, termEntries))
         if len(singularunits) == 0:
@@ -399,7 +354,7 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
 
         for entry in singularunits:
             term = self.UnitClass.createfromxmlElement(entry, namespace=self.namespace)
-            if nextplural and six.text_type(term.getid()) == ("%s[0]" % nextplural.getid()):
+            if nextplural and str(term.getid()) == ("%s[0]" % nextplural.getid()):
                 self.addunit(nextplural, new=False)
                 nextplural = next(pluralunit_iter, None)
             else:
