@@ -179,6 +179,56 @@ JSON_GOI18N = b"""[
 ]
 """
 
+JSON_GOI18N_V2 = """{
+    "simple": "value",
+    "plural": {
+        "zero": "the plural form 0",
+        "one": "the plural form 1",
+        "two": "the plural form 2",
+        "few": "the plural form 3",
+        "many": "the plural form 4",
+        "other": "the plural form 5"
+    }
+}
+"""
+
+JSON_GOI18N_V2_PLURAL = """{
+    "simple": "value",
+    "plural": "plural"
+}
+"""
+
+
+JSON_GOI18N_V2_SIMPLE = """{
+    "key": "value",
+    "table": {
+        "description": "an article of furniture consisting of a flat, slablike top supported on one or more legs or other supports",
+        "other": "Table"
+    },
+    "tag": {
+        "description": "a piece or strip of strong paper, plastic, metal, leather, etc., for attaching by one end to something as a mark or label",
+        "one": "{{.count}} tag",
+        "other": "{{.count}} tags"
+    }
+}
+"""
+
+JSON_GOI18N_V2_COMPLEXE = """{
+    "key": {
+        "other": "value"
+    },
+    "table": {
+        "description": "an article of furniture consisting of a flat, slablike top supported on one or more legs or other supports",
+        "other": "Table"
+    },
+    "tag": {
+        "description": "a piece or strip of strong paper, plastic, metal, leather, etc., for attaching by one end to something as a mark or label",
+        "one": "{{.count}} tag",
+        "other": "{{.count}} tags"
+    }
+}
+"""
+
 JSON_ARB = b"""{
   "@@last_modified": "2019-11-06T22:41:37.002648",
   "Back": "Back",
@@ -927,6 +977,24 @@ class TestI18NextV4Store(test_monolingual.TestMonolingualStore):
 
         assert bytes(store).decode() == EXPECTED
 
+    def test_ru(self):
+        data = """{
+"bet_one": "еще +{{count}} ставка",
+"bet_few": "еще +{{count}} ставки",
+"bet_many": "еще +{{count}} ставок"
+}
+"""
+        store = self.StoreClass()
+        store.settargetlanguage("ru")
+        store.parse(data)
+
+        assert len(store.units) == 1
+        assert store.units[0].source.strings == [
+            "еще +{{count}} ставка",
+            "еще +{{count}} ставки",
+            "еще +{{count}} ставок",
+        ]
+
 
 class TestGoI18NJsonFile(test_monolingual.TestMonolingualStore):
     StoreClass = jsonl10n.GoI18NJsonFile
@@ -952,6 +1020,68 @@ class TestGoI18NJsonFile(test_monolingual.TestMonolingualStore):
         assert '"other": ""' in bytes(store).decode()
 
 
+class TestGoI18NV2JsonFile(test_monolingual.TestMonolingualStore):
+    StoreClass = jsonl10n.GoI18NV2JsonFile
+
+    def test_plurals_1(self):
+        store = self.StoreClass()
+        store.parse(JSON_GOI18N_V2_SIMPLE)
+
+        assert len(store.units) == 3
+        assert store.units[0].target == "value"
+        assert store.units[1].target == "Table"
+        assert store.units[2].target == multistring(
+            ["{{.count}} tag", "{{.count}} tags"]
+        )
+
+        assert bytes(store).decode() == JSON_GOI18N_V2_SIMPLE
+
+    def test_plurals_2(self):
+        store = self.StoreClass()
+        store.settargetlanguage("ar")
+        store.parse(JSON_GOI18N_V2)
+
+        # Remove plurals
+        store.units[1].target = "plural"
+
+        assert bytes(store).decode() == JSON_GOI18N_V2_PLURAL
+
+        # Bring back plurals
+        store.units[1].target = multistring(
+            [
+                "the plural form 0",
+                "the plural form 1",
+                "the plural form 2",
+                "the plural form 3",
+                "the plural form 4",
+                "the plural form 5",
+            ]
+        )
+
+        assert bytes(store).decode() == JSON_GOI18N_V2
+
+    def test_plurals_missing(self):
+        store = self.StoreClass()
+        store.parse(JSON_GOI18N_V2_SIMPLE)
+
+        store.units[2].target = multistring(["{{.count}} tag"])
+
+        assert '"other": "{{.count}} tag"' in bytes(store).decode()
+
+    def test_simplification(self):
+        store = self.StoreClass()
+        store.parse(JSON_GOI18N_V2_COMPLEXE)
+
+        assert len(store.units) == 3
+        assert store.units[0].target == "value"
+        assert store.units[1].target == "Table"
+        assert store.units[2].target == multistring(
+            ["{{.count}} tag", "{{.count}} tags"]
+        )
+
+        assert bytes(store).decode() == JSON_GOI18N_V2_SIMPLE
+
+
 class TestARBJsonFile(test_monolingual.TestMonolingualStore):
     StoreClass = jsonl10n.ARBJsonFile
 
