@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009, 2013 Zuza Software Foundation
 # Copyright 2013 F Wolff
@@ -23,7 +22,6 @@
 import logging
 import math
 import re
-import six
 import threading
 import time
 from sqlite3 import dbapi2
@@ -32,11 +30,10 @@ from translate.lang import data
 from translate.search.lshtein import LevenshteinComparer
 
 
-STRIP_REGEXP = re.compile("\W", re.UNICODE)
+STRIP_REGEXP = re.compile(r"\W", re.UNICODE)
 
 
 class LanguageError(Exception):
-
     def __init__(self, value):
         self.value = value
 
@@ -44,18 +41,16 @@ class LanguageError(Exception):
         return str(self.value)
 
 
-class TMDB(object):
+class TMDB:
     _tm_dbs = {}
 
-    def __init__(self, db_file, max_candidates=3, min_similarity=75,
-                 max_length=1000):
-
+    def __init__(self, db_file, max_candidates=3, min_similarity=75, max_length=1000):
         self.max_candidates = max_candidates
         self.min_similarity = min_similarity
         self.max_length = max_length
 
-        if not isinstance(db_file, six.text_type):
-            db_file = six.text_type(db_file)  # don't know which encoding
+        if not isinstance(db_file, str):
+            db_file = str(db_file)  # don't know which encoding
         self.db_file = db_file
         # share connections to same database file between different instances
         if db_file not in self._tm_dbs:
@@ -72,9 +67,9 @@ class TMDB(object):
         self.preload_db()
 
     def _get_connection(self, index):
-        current_thread = threading.currentThread()
+        current_thread = threading.current_thread()
         if current_thread not in self._tm_db:
-            connection = dbapi2.connect(self.db_file.encode('utf-8') if six.PY2 else self.db_file)
+            connection = dbapi2.connect(self.db_file)
             cursor = connection.cursor()
             self._tm_db[current_thread] = (connection, cursor)
         return self._tm_db[current_thread][index]
@@ -134,7 +129,9 @@ DROP TABLE test_for_fts3;
             logging.debug("fts3 supported")
             # for some reason CREATE VIRTUAL TABLE doesn't support IF NOT
             # EXISTS syntax check if fulltext index table exists manually
-            self.cursor.execute("SELECT name FROM sqlite_master WHERE name = 'fulltext'")
+            self.cursor.execute(
+                "SELECT name FROM sqlite_master WHERE name = 'fulltext'"
+            )
             if not self.cursor.fetchone():
                 # create fulltext index table, and index all strings in sources
                 script = """
@@ -187,7 +184,7 @@ DROP TRIGGER IF EXISTS sources_delete_trig;
             query = """SELECT COUNT(*) FROM sources s JOIN targets t on s.sid = t.sid"""
         self.cursor.execute(query)
         (numrows,) = self.cursor.fetchone()
-        logging.debug("tmdb has %d records" % numrows)
+        logging.debug("tmdb has %d records", numrows)
         return numrows
 
     def add_unit(self, unit, source_lang=None, target_lang=None, commit=True):
@@ -218,28 +215,26 @@ DROP TRIGGER IF EXISTS sources_delete_trig;
         target_lang = data.normalize_code(target_lang)
         try:
             try:
-                self.cursor.execute("INSERT INTO sources (text, context, lang, length) VALUES(?, ?, ?, ?)",
-                                    (unit["source"],
-                                     unit["context"],
-                                     source_lang,
-                                     len(unit["source"])))
+                self.cursor.execute(
+                    "INSERT INTO sources (text, context, lang, length) VALUES(?, ?, ?, ?)",
+                    (unit["source"], unit["context"], source_lang, len(unit["source"])),
+                )
                 sid = self.cursor.lastrowid
             except dbapi2.IntegrityError:
                 # source string already exists in db, run query to find sid
-                self.cursor.execute("SELECT sid FROM sources WHERE text=? AND context=? and lang=?",
-                                    (unit["source"],
-                                     unit["context"],
-                                     source_lang))
+                self.cursor.execute(
+                    "SELECT sid FROM sources WHERE text=? AND context=? and lang=?",
+                    (unit["source"], unit["context"], source_lang),
+                )
                 sid = self.cursor.fetchone()
                 (sid,) = sid
             try:
                 # FIXME: get time info from translation store
                 # FIXME: do we need so store target length?
-                self.cursor.execute("INSERT INTO targets (sid, text, lang, time) VALUES (?, ?, ?, ?)",
-                                    (sid,
-                                     unit["target"],
-                                     target_lang,
-                                     int(time.time())))
+                self.cursor.execute(
+                    "INSERT INTO targets (sid, text, lang, time) VALUES (?, ?, ?, ?)",
+                    (sid, unit["target"], target_lang, int(time.time())),
+                )
             except dbapi2.IntegrityError:
                 # target string already exists in db, do nothing
                 pass
@@ -276,26 +271,25 @@ DROP TRIGGER IF EXISTS sources_delete_trig;
 
     def translate_unit(self, unit_source, source_langs, target_langs):
         """return TM suggestions for unit_source"""
-        if isinstance(unit_source, bytes):
-            unit_source = unit_source.decode("utf-8")
         if isinstance(source_langs, list):
             source_langs = [data.normalize_code(lang) for lang in source_langs]
-            source_langs = ','.join(source_langs)
+            source_langs = ",".join(source_langs)
         else:
             source_langs = data.normalize_code(source_langs)
         if isinstance(target_langs, list):
             target_langs = [data.normalize_code(lang) for lang in target_langs]
-            target_langs = ','.join(target_langs)
+            target_langs = ",".join(target_langs)
         else:
             target_langs = data.normalize_code(target_langs)
 
         minlen = min_levenshtein_length(len(unit_source), self.min_similarity)
-        maxlen = max_levenshtein_length(len(unit_source), self.min_similarity,
-                                        self.max_length)
+        maxlen = max_levenshtein_length(
+            len(unit_source), self.min_similarity, self.max_length
+        )
 
         # split source into words, remove punctuation and special
         # chars, keep words that are at least 3 chars long
-        unit_words = STRIP_REGEXP.sub(' ', unit_source).split()
+        unit_words = STRIP_REGEXP.sub(" ", unit_source).split()
         unit_words = list(filter(lambda word: len(word) > 2, unit_words))
 
         if self.fulltext and len(unit_words) > 3:
@@ -304,30 +298,31 @@ DROP TRIGGER IF EXISTS sources_delete_trig;
                        WHERE s.lang IN (?) AND t.lang IN (?) AND s.length BETWEEN ? AND ?
                        AND fulltext MATCH ?"""
             search_str = " OR ".join(unit_words)
-            self.cursor.execute(query, (source_langs, target_langs, minlen,
-                                maxlen, search_str))
+            self.cursor.execute(
+                query, (source_langs, target_langs, minlen, maxlen, search_str)
+            )
         else:
             logging.debug("nonfulltext matching")
             query = """SELECT s.text, t.text, s.context, s.lang, t.lang FROM sources s JOIN targets t ON s.sid = t.sid
             WHERE s.lang IN (?) AND t.lang IN (?)
             AND s.length >= ? AND s.length <= ?"""
-            self.cursor.execute(query, (source_langs, target_langs, minlen,
-                                        maxlen))
+            self.cursor.execute(query, (source_langs, target_langs, minlen, maxlen))
 
         results = []
         for row in self.cursor:
-            quality = self.comparer.similarity(unit_source, row[0],
-                                               self.min_similarity)
+            quality = self.comparer.similarity(unit_source, row[0], self.min_similarity)
             if quality >= self.min_similarity:
-                results.append({
-                    'source': row[0],
-                    'target': row[1],
-                    'context': row[2],
-                    'quality': quality,
-                })
-        results.sort(key=lambda match: match['quality'], reverse=True)
-        results = results[:self.max_candidates]
-        logging.debug("results: %s", six.text_type(results))
+                results.append(
+                    {
+                        "source": row[0],
+                        "target": row[1],
+                        "context": row[2],
+                        "quality": quality,
+                    }
+                )
+        results.sort(key=lambda match: match["quality"], reverse=True)
+        results = results[: self.max_candidates]
+        logging.debug("results: %s", str(results))
         return results
 
 
